@@ -7,9 +7,13 @@
 
 /* .C calls */
 extern void ProjSep(void *, void *, void *, void *);
+extern void lrs_XuHe (void*, void*, void*, void*, void*, void*, void*);
+extern void selectlss(void*, void*, void*, void*, void*, void*, void*, void*, void*, void*);
 
 static const R_CMethodDef CEntries[] = {
     {"ProjSep", (DL_FUNC) &ProjSep, 4},
+    {"lrs_XuHe", (DL_FUNC) &lrs_XuHe, 7},
+    {"selectlss", (DL_FUNC) &selectlss, 10},
     {NULL, NULL, 0}
 };
 
